==> casex-1.0.4.tar.gz: casex-1.0.4/README.md <==
Implementation of the mathematics behind JARUS WG-6 SORA Annex F.

Overview
--------
This package was created to support the mathematical models used to derive
the iGRC tables and supporting material found in JARUS WG-6 SORA Annex F.
It implements the models for computing critical areas, effect of obstacles,
ballistic descent, effect of explosions and deflagration that are being used
in Annex F. It also includes easy access to the specific choice of parameters
that are used in Annex F. Finally, this package can be used for easily recreating some of the figures found
in Annex F.

The mathematical models implemented in the package are the results of the
combined effort of the Quantitative Methods subgroup under Working Group 6.

Installation
------------
To install CasEx, simply run the following command in your terminal.

::

    pip install casex

Documentation
-------------
The full documentation for CasEx is located at https://casex.readthedocs.io/.

License
-------
This toolbox is under license CC BY 4.0. This means that you are free to copy and redistribute the material in any medium or format, as well as to remix, transform, and build upon the material
for any purpose, even commercially. The licensor cannot revoke these freedoms as long as you follow the license terms.
You may not apply legal terms or technological measures that legally restrict others from doing anything the license permits.

Do note that according to this license you must give appropriate credit, provide a link to the license, and indicate if changes were made. You may do so in any reasonable manner, but not in any way that suggests the licensor endorses you or your use.

We recommend the following reference to CasEx:

::

    CasEx: Casual Expectation Toolbox in Python. JARUS WG6 Quantitative Methods subgroup, 2021. Available at https://casex.readthedocs.io.

And as BibTeX:

::

    @misc{JARUSWG6QuantitativeMethodssubgroup2021,
        author = {{JARUS WG6 Quantitative Methods subgroup}},
        title = {{CasEx: Casual Expectation Toolbox in Python}},
        url = {casex.readthedocs.io},
        year = {2021}
    }

==> casex-1.0.5.tar.gz: casex-1.0.5/README.md <==
Implementation of the mathematics behind JARUS WG-6 SORA Annex F.

Overview
--------
This package was created to support the mathematical models used to derive
the iGRC tables and supporting material found in JARUS WG-6 SORA Annex F.
It implements the models for computing critical areas, effect of obstacles,
ballistic descent, effect of explosions and deflagration that are being used
in Annex F. It also includes easy access to the specific choice of parameters
that are used in Annex F. Finally, this package can be used for easily recreating some of the figures found
in Annex F.

The mathematical models implemented in the package are the results of the
combined effort of the Quantitative Methods subgroup under Working Group 6.

Installation
------------
To install CasEx, simply run the following command in your terminal.

    pip install casex

Documentation
-------------
The full documentation for CasEx is located at https://casex.readthedocs.io/.

License
-------
This toolbox is under license CC BY 4.0. This means that you are free to copy and redistribute the material in any medium or format, as well as to remix, transform, and build upon the material
for any purpose, even commercially. The licensor cannot revoke these freedoms as long as you follow the license terms.
You may not apply legal terms or technological measures that legally restrict others from doing anything the license permits.

Do note that according to this license you must give appropriate credit, provide a link to the license, and indicate if changes were made. You may do so in any reasonable manner, but not in any way that suggests the licensor endorses you or your use.

We recommend the following reference to CasEx:

::
    CasEx: Casual Expectation Toolbox in Python. JARUS WG-6 SORA Annex F Quantitative Methods subgroup, 2021. Available at https://casex.readthedocs.io.

And as BibTeX:


    @misc{JARUSWG6QuantitativeMethodssubgroup2021,
    author = {{JARUS WG-6 SORA Annex F Quantitative Methods subgroup}},
    title = {{CasEx: Casual Expectation Toolbox in Python}},
    url = {casex.readthedocs.io},
    year = {2021}
    }
